import {
  Controller,
  ForbiddenException,
  Get,
  Query,
  Request,
  UseGuards,
} from '@nestjs/common';
import { AuthGuard } from '@nestjs/passport';
import {
  ApiBearerAuth,
  ApiOperation,
  ApiQuery,
  ApiTags,
} from '@nestjs/swagger';
import { Serealize } from '../interceptors/serialize.interceptor';
import { CaritoMotivoService } from './carrito-motivo.service';
import { Operador } from '../operador/entity/operador.entity';
import { GetDto } from './dto/input/get.dto';
import { CarritoMotivoOutputDto } from './dto/output/carrito-motivo.dto';

@Controller('carrito-motivo')
@ApiTags('carrito-motivo')
export class CarritoMotivoController {
  constructor(private carritoMotivoService: CaritoMotivoService) {}

  @Serealize(CarritoMotivoOutputDto)
  @Get()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({
    description:
      'Endpoint que retorna 25 cambios de status que ha tenido un carrito dependiendo de la página en la que se encuentra el alumno.',
  })
  @ApiBearerAuth('jwt')
  @ApiQuery({
    description: 'Id del carrito.',
    name: 'id_carrito',
    type: 'string',
  })
  @ApiQuery({
    description: 'Página en la que se encuentra el usuario.',
    name: 'pagina',
    type: 'string',
  })
  get(@Request() req, @Query() query: GetDto) {
    const operador: Operador = req.user.operador;

    if (
      !operador ||
      (operador.tipoUsuario.id_tipo_usuario != 3 &&
        operador.tipoUsuario.id_tipo_usuario != 4)
    )
      throw new ForbiddenException(
        'No tienes los permisos necesarios para acceder a esta información.',
      );
    return this.carritoMotivoService.findAllByIdCarrito(
      parseInt(query.id_carrito),
      parseInt(query.pagina),
    );
  }

  // @Get('reporte')
  // reporte() {}
}
