import * as moment from 'moment';
import { forwardRef, Inject, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Repository } from 'typeorm';
import { Carrito } from 'src/carrito/entity/carrito.entity';
import { CarritoMotivo } from './entity/carrito-motivo.entity';
import { Operador } from '../operador/entity/operador.entity';
import { CarritoService } from '../carrito/carrito.service';
import { OperadorService } from '../operador/operador.service';

@Injectable()
export class CaritoMotivoService {
  constructor(
    @InjectRepository(CarritoMotivo)
    private repository: Repository<CarritoMotivo>,
    @Inject(forwardRef(() => CarritoService))
    private carritoService: CarritoService,
    private operadorService: OperadorService,
  ) {}

  async create(
    carrito: Carrito,
    operador: Operador,
    status: boolean,
    motivo: string,
  ) {
    const ahora = moment();

    return this.repository.save(
      this.repository.create({
        carrito,
        fecha_creacion: ahora.toDate(),
        motivo,
        operador,
        status,
      }),
    );
  }

  findAllByIdCarrito(id_carrito: number, pagina: number) {
    return this.carritoService.findById(id_carrito).then((carrito) =>
      this.repository.findAndCount({
        where: { carrito },
        skip: (pagina - 1) * 25,
        take: 25,
      }),
    );
  }
}
