import {
  Body,
  Controller,
  Delete,
  ForbiddenException,
  Post,
  Request,
  UseGuards,
} from '@nestjs/common';
import { AuthGuard } from '@nestjs/passport';
import { ApiBearerAuth, ApiBody, ApiOperation, ApiTags } from '@nestjs/swagger';
import { EquipoTipoEntradaService } from './equipo-tipo-entrada.service';
import { Operador } from 'src/operador/entity/operador.entity';
import { CreateEquipoTipoEntradaDto } from './dto/input/create.dto';
import { DeleteEquipoTipoEntradaDto } from './dto/input/delete.dto';

@Controller('equipo-tipo-entrada')
@ApiTags('equipo-tipo-entrada')
export class EquipoTipoEntradaController {
  constructor(private equipoTipoEntradaService: EquipoTipoEntradaService) {}

  @Post()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({
    description:
      'Endpoint que crea una relación entre un equipo y un tipo de entrada.',
  })
  @ApiBearerAuth('jwt')
  @ApiBody({
    description: 'Ambas variables son obligatorios.',
    examples: { ejemplo: { value: { id_equipo: 1, id_tipo_entrada: 1 } } },
  })
  create(@Request() req, @Body() body: CreateEquipoTipoEntradaDto) {
    const operador: Operador = req.user.operador;

    if (
      !operador ||
      (operador.tipoUsuario.id_tipo_usuario != 3 &&
        operador.tipoUsuario.id_tipo_usuario != 4)
    )
      throw new ForbiddenException(
        'No tienes los permisos necesarios para realizar esta acción.',
      );
    return this.equipoTipoEntradaService.create(
      body.id_equipo,
      body.id_tipo_entrada,
    );
  }

  @Delete()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({
    description:
      'Endpoint que elimina una relación entre un equipo y un tipo de entrada.',
  })
  @ApiBearerAuth('jwt')
  @ApiBody({
    description: 'La variable id_equipo_tipo_entrada es obligatoria.',
    examples: { ejemplo: { value: { id_equipo_tipo_entrada: 1 } } },
  })
  delete(@Request() req, @Body() body: DeleteEquipoTipoEntradaDto) {
    const operador: Operador = req.user.operador;

    if (
      !operador ||
      (operador.tipoUsuario.id_tipo_usuario != 3 &&
        operador.tipoUsuario.id_tipo_usuario != 4)
    )
      throw new ForbiddenException(
        'No tienes los permisos necesarios para realizar esta acción.',
      );
    return this.equipoTipoEntradaService.delete(body.id_equipo_tipo_entrada);
  }
}
