import { ConflictException, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Repository } from 'typeorm';
import { InstitucionCarrera } from '../institucion-carrera/entity/institucion-carrera.entity';
import { InstitucionUsuario } from './entity/institucion-usuario.entity';
import { Usuario } from '../usuario/entity/usuario.entity';

@Injectable()
export class InstitucionUsuarioService {
  constructor(
    @InjectRepository(InstitucionUsuario)
    private repository: Repository<InstitucionUsuario>,
  ) {}

  create(institucionCarrera: InstitucionCarrera, usuario: Usuario) {
    return this.repository
      .save(this.repository.create({ institucionCarrera, usuario }))
      .then((institucionUsuario) => ({
        message: `Se asignó la carrera: ${institucionUsuario.institucionCarrera.carrera.carrera} al usuario: ${institucionUsuario.usuario.usuario}.`,
        institucionUsuario,
      }));
  }

  findById(id_institucion_usuario: number) {
    return this.repository
      .findOne({ id_institucion_usuario })
      .then((institucionUsuario) => {
        if (!institucionUsuario)
          throw new ConflictException('No existe este id institución usuario.');
        return institucionUsuario;
      });
  }

  findByUsuarioInstitucionCarrera(
    usuario: Usuario,
    institucionCarrera: InstitucionCarrera,
    campo: string,
  ) {
    return this.repository
      .findOne({
        activo: true,
        institucionCarrera,
        usuario,
      })
      .then((institucionUsuario) => {
        if (!institucionUsuario)
          throw new ConflictException(
            'Verificar sus datos, cualquier duda asistir al módulo PC PUMA.',
          );
        return institucionUsuario;
      });
  }

  update(attrs: Partial<InstitucionUsuario>) {
    return this.findById(attrs.id_institucion_usuario).then(
      (institucionUsuario) => {
        Object.assign(institucionUsuario, attrs);
        return this.repository.save(institucionUsuario);
      },
    );
  }
}
