import { forwardRef, Module } from '@nestjs/common';
import { PassportModule } from '@nestjs/passport';
import { TypeOrmModule } from '@nestjs/typeorm';
import { AppGateway } from '../app.gateway';
import { PrestamoController } from './prestamo.controller';
import { PrestamoService } from './prestamo.service';
import { Prestamo } from './entity/prestamo.entity';
import { EquipoModule } from '../equipo/equipo.module';
import { InstitucionModule } from '../institucion/institucion.module';
import { InstitucionDiaModule } from '../institucion-dia/institucion-dia.module';
import { InstitucionProgramaModule } from '../institucion-programa/institucion-programa.module';
import { InstitucionTipoCarritoModule } from '../institucion-tipo-carrito/institucion-tipo-carrito.module';
import { InstitucionTipoEntradaModule } from '../institucion-tipo-entrada/institucion-tipo-entrada.module';
import { OperadorModule } from '../operador/operador.module';
import { ModuloModule } from '../modulo/modulo.module';
import { MultaModule } from '../multa/multa.module';
import { TipoUsuarioModule } from '../tipo-usuario/tipo-usuario.module';
import { UsuarioModule } from '../usuario/usuario.module';
@Module({
  imports: [
    EquipoModule,
    InstitucionModule,
    InstitucionDiaModule,
    InstitucionProgramaModule,
    InstitucionTipoCarritoModule,
    InstitucionTipoEntradaModule,
    ModuloModule,
    forwardRef(() => MultaModule),
    OperadorModule,
    PassportModule.register({ defaultStrategy: 'jwt' }),
    TypeOrmModule.forFeature([Prestamo]),
    TipoUsuarioModule,
    UsuarioModule,
  ],
  controllers: [PrestamoController],
  providers: [AppGateway, PrestamoService],
  exports: [PrestamoService],
})
export class PrestamoModule {}
