import {
  Controller,
  ForbiddenException,
  Get,
  Request,
  UseGuards,
} from '@nestjs/common';
import { AuthGuard } from '@nestjs/passport';
import { ApiBearerAuth, ApiOperation, ApiTags } from '@nestjs/swagger';
import { Serealize } from '../interceptors/serialize.interceptor';
import { StatusService } from './status.service';
import { StatusOutputDto } from './dto/output/status.dto';
import { Operador } from 'src/operador/entity/operador.entity';

@Controller('status')
@ApiTags('status')
export class StatusController {
  constructor(private statusService: StatusService) {}

  @Serealize(StatusOutputDto)
  @Get()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({ description: 'Endpoint que retorna todos los status.' })
  @ApiBearerAuth('jwt')
  get(@Request() req) {
    const operador: Operador = req.user.operador;

    if (
      !operador ||
      (operador.tipoUsuario.id_tipo_usuario != 2 &&
        operador.tipoUsuario.id_tipo_usuario != 3 &&
        operador.tipoUsuario.id_tipo_usuario != 4)
    )
      throw new ForbiddenException(
        'No tienes los permisos necesarios para acceder a esta información.',
      );
    return this.statusService.findAll();
  }
}
