import {
  Body,
  ConflictException,
  Controller,
  Get,
  Post,
  Request,
  UseGuards,
} from '@nestjs/common';
import { AuthGuard } from '@nestjs/passport';
import { ApiBearerAuth, ApiBody, ApiOperation, ApiTags } from '@nestjs/swagger';
import { Serealize } from '../interceptors/serialize.interceptor';
import { TipoUsuarioService } from './tipo-usuario.service';
import { Operador } from 'src/operador/entity/operador.entity';
import { CreateTipoUsuarioDto } from './dto/input/create.dto';
import { TipoUsuarioOutputDto } from './dto/output/tipo-usuario.dto';

@Controller('tipo-usuario')
@ApiTags('tipo-usuario')
export class TipoUsuarioController {
  constructor(private tipoUsuarioService: TipoUsuarioService) {}

  @Post()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({ description: 'Endpoint que crea un nuevo tipo de usuario.' })
  @ApiBearerAuth('jwt')
  @ApiBody({
    description: 'Es obligatorio mandar el campo tipo_usuario.',
    examples: { ejemplo: { value: { tipo_usuario: '' } } },
  })
  create(@Request() req, @Body() body: CreateTipoUsuarioDto) {
    const superAdmin: Operador = req.user.operador;

    if (!superAdmin || superAdmin.tipoUsuario.id_tipo_usuario != 2)
      throw new ConflictException(
        'No tienes los permisos necesarios para realizar esta acción.',
      );
    return this.tipoUsuarioService.create(body.tipo_usuario);
  }

  @Serealize(TipoUsuarioOutputDto)
  @Get()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({
    description: 'Endpoint que retorna todos los tipos de usuario.',
  })
  @ApiBearerAuth('jwt')
  get(@Request() req) {
    const superAdmin: Operador = req.user.operador;

    if (!superAdmin || superAdmin.tipoUsuario.id_tipo_usuario != 2)
      throw new ConflictException(
        'No tienes los permisos necesarios para realizar esta acción.',
      );
    return this.tipoUsuarioService.findAll();
  }

  @Serealize(TipoUsuarioOutputDto)
  @Get('operador')
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({
    description:
      'Endpoint que retorna todos los tipos de usuario que debe ver un operador.',
  })
  @ApiBearerAuth('jwt')
  operador(@Request() req) {
    const operador: Operador = req.user.operador;

    if (
      !operador ||
      (operador.tipoUsuario.id_tipo_usuario != 2 &&
        operador.tipoUsuario.id_tipo_usuario != 3 &&
        operador.tipoUsuario.id_tipo_usuario != 4)
    )
      throw new ConflictException(
        'No tienes los permisos necesarios para realizar esta acción.',
      );
    return this.tipoUsuarioService.findAll('operador');
  }
}
